<?php

namespace Drupal\media_twig_tools\Config;

/**
 * Configuration for MediaTwigTools settings.
 *
 * @package Drupal\media_twig_tools\Config
 */
interface MediaTwigToolsConfigInterface {

  /**
   * Serivce name.
   *
   * @const string
   */
  public const SERVICE_NAME = 'media_twig_tools.config';

  /**
   * Field dirname.
   *
   * @const string
   */
  public const FIELD_DIRNAME = 'dirname';

  /**
   * Field no style.
   *
   * @const string
   */
  public const FIELD_NO_STYLE = 'no_style';

  /**
   * Default no style identifier.
   *
   * @const string
   */
  public const DEFAULT_NO_STYLE_IDENTIFIER = 'unstyle';

  /**
   * Allow max size field.
   *
   * @const string
   */
  public const FIELD_ALLOW_MAX_SIZE = 'allow_max_size';

  /**
   * Enable format bounce.
   *
   * @const string
   */
  public const FIELD_ENABLE_FORMAT_BOUNCE = 'enable_format_bounce';

  /**
   * Enable Oversize check.
   *
   * @const string
   */
  public const FIELD_ENABLE_OVERSIZE_CHECK = 'enable_oversize_check';

  /**
   * Return true if $value is a valid no style identifier.
   *
   * @param string $value
   *   The value.
   *
   * @return bool
   *   The result.
   */
  public function existsNoStyleIdentifier($value);

  /**
   * Return the dirname.
   *
   * @return string
   *   The dirname.
   */
  public function getDirname();

  /**
   * Update the dirname.
   *
   * @param string $dirname
   *   The dirname.
   *
   * @return MediaTwigToolsConfig
   *   The config.
   */
  public function setDirname($dirname);

  /**
   * Return the no style identifier.
   *
   * @return string
   *   The no style identifier.
   */
  public function getNoStyle();

  /**
   * Update the no style identifier.
   *
   * @param string $noStyle
   *   The no style identifier.
   *
   * @return MediaTwigToolsConfig
   *   The config.
   */
  public function setNoStyle($noStyle);

  /**
   * REturn the file storage.
   *
   * @return \Drupal\Core\Entity\EntityStorageInterface
   *   The file storage.
   */
  public function getFileStorage();

  /**
   * Return the image style storage.
   *
   * @return \Drupal\Core\Entity\EntityStorageInterface
   *   The image style storage.
   */
  public function getImageStyleStorage();

  /**
   * Return the allowed max size.
   *
   * @return string|null
   *   The allowed max size.
   */
  public function getAllowMaxSize();

  /**
   * Update the allowed max size.
   *
   * @param string $allowMaxSize
   *   The allowed max size.
   *
   * @return MediaTwigToolsConfig
   *   The config.
   */
  public function setAllowMaxSize($allowMaxSize);

  /**
   * Return the format bounce feature enable status.
   *
   * @return bool
   *   The format bounce feature status.
   */
  public function isFormatBounceEnable();

  /**
   * Update the format bounce feature enable status.
   *
   * @param bool $enable
   *   The status.
   *
   * @return MediaTwigToolsConfig
   *   The config.
   */
  public function enableFormatBounce($enable = TRUE);

  /**
   * Return the oversize check enable status.
   *
   * @return bool
   *   The oversize check feature status.
   */
  public function isOversizeCheckEnable();

  /**
   * Update the oversize check feature status.
   *
   * @param bool $enable
   *   The status.
   *
   * @return MediaTwigToolsConfig
   *   The config.
   */
  public function enableOversizeCheck($enable = TRUE);

}
